@@ -117,6 +117,8 @@ class OplogThread(threading.Thread):
             err = False
             try:
                 for entry in cursor:
+                    if 'fromMigrate' in entry and entry['fromMigrate'] is True:
+                        continue
                     #sync the current oplog operation
                     operation = entry['op']
                     ns = entry['ns']
@@ -153,8 +155,6 @@ class OplogThread(threading.Thread):
                 self.checkpoint = last_ts
                 self.update_checkpoint()
 
-            time.sleep(2)
-
     def join(self):
         """Stop this thread from managing the oplog.
         """
@@ -266,16 +266,10 @@ class OplogThread(threading.Thread):
                     doc['ns'] = namespace
                     doc['_ts'] = long_ts
                     self.doc_manager.upsert(doc)
-            except pymongo.errors.AutoReconnect as e:
+            except (pymongo.errors.AutoReconnect,
+                    pymongo.errors.OperationFailure) as e:
                 err_msg = "OplogManager: Failed during dump collection. "
-                err_msg += "AutoReconnect error: %s." % e 
-                effect = " Cannot recover!"
-                logging.error('%s %s %s' % (err_msg, effect, self.oplog))
-                self.running = False
-                return
-            except pymongo.errors.OperationFailure as e:
-                err_msg = "OplogManager: Failed during dump collection"
-                err_msg += "OperationFailure error: %s." % e
+                err_msg += "Error: %s." % e 
                 effect = " Cannot recover!"
                 logging.error('%s %s %s' % (err_msg, effect, self.oplog))
                 self.running = False
